.. _masker_report_examples_ref:

.. only:: html

Examples nifti masker reports
=============================

Nifti masker
------------

Adapted from :ref:`sphx_glr_auto_examples_06_manipulating_images_plot_nifti_simple.py`

.. raw:: html
   :file: nifti_masker.html

Adapted from :ref:`sphx_glr_auto_examples_02_decoding_plot_miyawaki_encoding.py`

.. raw:: html
   :file: multi_nifti_masker.html

.. raw:: html
   :file: multi_nifti_masker_fitted.html


Nifti labels masker
-------------------

Adapted from :ref:`sphx_glr_auto_examples_06_manipulating_images_plot_nifti_labels_simple.py`

.. raw:: html
   :file: nifti_labels_masker_fitted.html

.. raw:: html
   :file: nifti_labels_masker_atlas.html

Adapted from :ref:`sphx_glr_auto_examples_03_connectivity_plot_atlas_comparison.py`

.. raw:: html
   :file: multi_nifti_labels_masker_atlas.html

.. raw:: html
   :file: multi_nifti_labels_masker_fitted.html

Nifti maps masker
-----------------

Adapted from :ref:`sphx_glr_auto_examples_03_connectivity_plot_probabilistic_atlas_extraction.py`

.. raw:: html
   :file: nifti_maps_masker.html

Adapted from :ref:`sphx_glr_auto_examples_03_connectivity_plot_atlas_comparison.py`

.. raw:: html
   :file: multi_nifti_maps_masker_atlas.html

.. raw:: html
   :file: multi_nifti_maps_masker_fitted.html

Nifti sphere masker
-------------------

Adapted from :ref:`sphx_glr_auto_examples_04_glm_first_level_plot_adhd_dmn.py`

.. raw:: html
   :file: nifti_sphere_masker.html


.. raw:: html
   :file: nifti_sphere_masker_fitted.html

Examples surface masker reports
===============================

Surface masker
--------------

.. raw:: html
   :file: surface_masker.html

.. raw:: html
   :file: surface_masker_with_mask.html

Surface labels masker
---------------------

.. raw:: html
   :file: surface_label_masker_unfitted.html

.. raw:: html
   :file: surface_label_masker.html

Surface maps masker
-------------------

.. raw:: html
   :file: surface_maps_masker_plotly.html

.. raw:: html
   :file: surface_maps_masker_matplotlib.html
